@@ -93,6 +93,7 @@
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
+/* #undef HAVE_UCONTEXT_H */
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -214,7 +215,7 @@
 /* #undef HAVE_PORT_CREATE */
 /* #undef HAVE_POSIX_FALLOCATE */
 #define HAVE_PREAD 1
-#define HAVE_PAUSE_INSTRUCTION 1
+/* #undef HAVE_PAUSE_INSTRUCTION */
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
@@ -289,7 +290,6 @@
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
-/* #undef HAVE_UCONTEXT */
 #define HAVE_VALLOC 1
 #define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
@@ -346,10 +346,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define SIZEOF_CHAR 1
@@ -371,7 +371,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -414,7 +414,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -466,13 +466,13 @@
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-
+#define HAVE_ERR_remove_thread_state 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
-#define HAVE_GCC_ATOMIC_BUILTINS 1
+/* #undef HAVE_GCC_ATOMIC_BUILTINS */
 /* #undef HAVE_GCC_C11_ATOMICS */
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_DECL_SHM_HUGETLB */
@@ -488,11 +488,11 @@
 
 #define TIME_WITH_SYS_TIME 1
 
-#define STACK_DIRECTION -1
+#define STACK_DIRECTION 1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "amd64"
-#define DEFAULT_MACHINE "amd64"
+#define MACHINE_TYPE "hppa"
+#define DEFAULT_MACHINE "hppa"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -609,20 +609,20 @@
   Important storage engines (those that really need define 
   WITH_<ENGINE>_STORAGE_ENGINE for the whole server)
 */
-#define WITH_MYISAM_STORAGE_ENGINE 1
-#define WITH_MYISAMMRG_STORAGE_ENGINE 1
-#define WITH_HEAP_STORAGE_ENGINE 1
+/* #undef WITH_MYISAM_STORAGE_ENGINE */
+/* #undef WITH_MYISAMMRG_STORAGE_ENGINE */
+/* #undef WITH_HEAP_STORAGE_ENGINE */
 /* #undef WITH_INNOBASE_STORAGE_ENGINE */
-#define WITH_XTRADB_STORAGE_ENGINE 1
-#define WITH_CSV_STORAGE_ENGINE 1
-#define WITH_PARTITION_STORAGE_ENGINE 1
-#define WITH_PERFSCHEMA_STORAGE_ENGINE 1
+/* #undef WITH_XTRADB_STORAGE_ENGINE */
+/* #undef WITH_CSV_STORAGE_ENGINE */
+/* #undef WITH_PARTITION_STORAGE_ENGINE */
+/* #undef WITH_PERFSCHEMA_STORAGE_ENGINE */
 /* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
 #if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
 # define HAVE_NDB_BINLOG 1
 #endif
-#define WITH_ARIA_STORAGE_ENGINE 1
-#define USE_ARIA_FOR_TMP_TABLES 1
+/* #undef WITH_ARIA_STORAGE_ENGINE */
+/* #undef USE_ARIA_FOR_TMP_TABLES */
 
 #define DEFAULT_MYSQL_HOME "/usr/local"
 #define SHAREDIR "/usr/local/share/mysql"
@@ -637,16 +637,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 23
+#define MYSQL_VERSION_PATCH 25
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.23"
+#define PACKAGE_STRING "MySQL Server 10.0.25"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.23"
-#define VERSION "10.0.23"
+#define PACKAGE_VERSION "10.0.25"
+#define VERSION "10.0.25"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
